csep.core.catalogs.UCERF3Catalog
================================

.. currentmodule:: csep.core.catalogs

.. autoclass:: UCERF3Catalog

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~UCERF3Catalog.__init__
      ~UCERF3Catalog.apply_mct
      ~UCERF3Catalog.filter
      ~UCERF3Catalog.filter_spatial
      ~UCERF3Catalog.from_dataframe
      ~UCERF3Catalog.from_dict
      ~UCERF3Catalog.get_bvalue
      ~UCERF3Catalog.get_csep_format
      ~UCERF3Catalog.get_cumulative_number_of_events
      ~UCERF3Catalog.get_datetimes
      ~UCERF3Catalog.get_depths
      ~UCERF3Catalog.get_epoch_times
      ~UCERF3Catalog.get_event_ids
      ~UCERF3Catalog.get_latitudes
      ~UCERF3Catalog.get_longitudes
      ~UCERF3Catalog.get_mag_idx
      ~UCERF3Catalog.get_magnitudes
      ~UCERF3Catalog.get_number_of_events
      ~UCERF3Catalog.get_spatial_idx
      ~UCERF3Catalog.length_in_seconds
      ~UCERF3Catalog.load_catalog
      ~UCERF3Catalog.load_catalogs
      ~UCERF3Catalog.load_json
      ~UCERF3Catalog.magnitude_counts
      ~UCERF3Catalog.spatial_counts
      ~UCERF3Catalog.spatial_event_probability
      ~UCERF3Catalog.spatial_magnitude_counts
      ~UCERF3Catalog.to_dataframe
      ~UCERF3Catalog.to_dict
      ~UCERF3Catalog.update_catalog_stats
      ~UCERF3Catalog.write_ascii
      ~UCERF3Catalog.write_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~UCERF3Catalog.catalog
      ~UCERF3Catalog.data
      ~UCERF3Catalog.dtype
      ~UCERF3Catalog.event_count
      ~UCERF3Catalog.header_dtype
      ~UCERF3Catalog.log
   
   